"use client"

import { deleteGallery } from "@/actions/galleries/deleteGallery";
import { updateGallery } from "@/actions/galleries/updateGallery";
import { Button } from "@/components/ui/button";
import { Form, FormControl, FormDescription, FormField, FormItem, FormLabel, FormMessage } from "@/components/ui/form";
import { Input } from "@/components/ui/input";
import { Album, Gallery } from "@/generated/prisma";
import { gallerySchema } from "@/schemas/galleries/gallerySchema";
import { zodResolver } from "@hookform/resolvers/zod";
import { useRouter } from "next/navigation";
import { useForm } from "react-hook-form";
import { toast } from "sonner";
import * as z from "zod/v4";

export default function EditGalleryForm({ gallery }: { gallery: Gallery & { albums: Album[] } }) {
  const router = useRouter();
  const form = useForm<z.infer<typeof gallerySchema>>({
    resolver: zodResolver(gallerySchema),
    defaultValues: {
      name: gallery.name,
      slug: gallery.slug,
      description: gallery.description || "",
    },
  })

  async function onSubmit(values: z.infer<typeof gallerySchema>) {
    var updatedGallery = await updateGallery(values, gallery.id)
    if (updatedGallery) {
      toast.success("Gallery updated")
      router.push(`/galleries`)
    }
  }

  return (
    <div className="flex flex-col gap-8">
      <Form {...form}>
        <form onSubmit={form.handleSubmit(onSubmit)} className="space-y-8">
          <FormField
            control={form.control}
            name="name"
            render={({ field }) => (
              <FormItem>
                <FormLabel>Gallery name</FormLabel>
                <FormControl>
                  <Input placeholder="Gallery name" {...field} />
                </FormControl>
                <FormDescription>
                  This is your public display name.
                </FormDescription>
                <FormMessage />
              </FormItem>
            )}
          />
          <FormField
            control={form.control}
            name="slug"
            render={({ field }) => (
              <FormItem>
                <FormLabel>Gallery slug</FormLabel>
                <FormControl>
                  <Input placeholder="Gallery slug" {...field} />
                </FormControl>
                <FormDescription>
                  Will be used for the navigation.
                </FormDescription>
                <FormMessage />
              </FormItem>
            )}
          />
          <FormField
            control={form.control}
            name="description"
            render={({ field }) => (
              <FormItem>
                <FormLabel>Gallery description</FormLabel>
                <FormControl>
                  <Input placeholder="Gallery description" {...field} />
                </FormControl>
                <FormDescription>
                  Description of the gallery.
                </FormDescription>
                <FormMessage />
              </FormItem>
            )}
          />
          <div className="flex flex-col gap-4">
            <Button type="submit">Submit</Button>
            <Button type="reset" variant="secondary" onClick={() => router.back()}>Cancel</Button>
          </div>
        </form>
      </Form>
      <div className="pt-10">
        <h2 className="text-lg font-semibold mb-2">Albums in this Gallery</h2>
        {gallery.albums.length === 0 ? (
          <p className="text-muted-foreground italic">No albums yet.</p>
        ) : (
          <ul className="space-y-2">
            {gallery.albums.map((album) => (
              <li key={album.id} className="flex items-center justify-between border rounded px-4 py-2">
                <div className="space-y-1">
                  <div className="font-medium">{album.name}</div>
                  <div className="text-sm text-muted-foreground">Slug: {album.slug}</div>
                </div>
                <div className="text-sm text-right">
                  {/* Replace this with actual image count later */}
                  <span className="font-mono">Images: 0</span>
                </div>
              </li>
            ))}
          </ul>
        )}
      </div>
      <p className="text-sm text-muted-foreground">
        Total images in this gallery: <span className="font-semibold">0</span>
      </p>
      <div>
        {gallery.albums.length === 0 ? (
          <Button
            type="button"
            variant="destructive"
            onClick={async () => {
              await deleteGallery(gallery.id);
              toast.success("Gallery deleted");
              router.push("/galleries");
            }}
          >
            Delete Gallery
          </Button>
        ) : (
          <>
            <Button
              type="button"
              variant="destructive"
              disabled
              onClick={async () => {
                await deleteGallery(gallery.id);
                toast.success("Gallery deleted");
                router.push("/galleries");
              }}
            >
              Delete Gallery
            </Button>
            <p className="text-sm text-muted-foreground italic">
              You must remove all albums before deleting this gallery.
            </p>
          </>
        )}
      </div>
    </div>
  );
}